@@ -13,7 +13,7 @@ set -e -o pipefail
 source "$(dirname "$0")/setup-utils.sh"
 
 BTOR2TOOLS_DIR=${DEPS_DIR}/btor2tools
-COMMIT_ID="1df768d75adfb13a8f922f5ffdd1d58e80cb1cc2"
+COMMIT_ID="037f1fa88fb439dca6f648ad48a3463256d69d8b"
 
 download_github "boolector/btor2tools" "$COMMIT_ID" "$BTOR2TOOLS_DIR"
 cd "${BTOR2TOOLS_DIR}"
@@ -24,7 +24,18 @@ if is_windows; then
   test_apply_patch "${component}" "${last_patch_date}"
 fi
 
-./configure.sh -fPIC
-make -j${NPROC}
-install_lib build/libbtor2parser.a
+if is_macos; then
+   mkdir build
+   pushd build
+   cmake .. -DBUILD_SHARED_LIBS=OFF -DCMAKE_OSX_ARCHITECTURES='x86_64;arm64'
+   make -j${NPROC}
+   popd
+else
+  CFLAGS="-fPIC" ./configure.sh --static
+  pushd build
+  make -j${NPROC}
+  popd
+fi
+
+install_lib build/lib/libbtor2parser.a
 install_include src/btor2parser/btor2parser.h
