@@ -6,7 +6,7 @@
  *  See COPYING for more information on using this software.
  */
 
-#include "btor2parser/btor2parser.h"
+#include "btor2parser.h"
 #include "btormsg.h"
 #include "btorparse.h"
 #include "btortypes.h"
@@ -90,7 +90,7 @@ delete_btor2_parser (BtorBTOR2Parser *parser)
 
 static const char *
 parse_btor2_parser (BtorBTOR2Parser *parser,
-                    BtorCharStack *prefix,
+                    BtorIntStack *prefix,
                     FILE *infile,
                     const char *infile_name,
                     FILE *outfile,
